← Back to team overview

yade-dev team mailing list archive

[Branch ~yade-dev/yade/trunk] Rev 2000: Renaming of all (normally) linked with this famous "ContactLaw1". Thanks to Vaclav for his scripts !

 

------------------------------------------------------------
revno: 2000
committer: jduriez <jduriez@c1solimara-l>
branch nick: trunk
timestamp: Tue 2010-02-02 15:27:14 +0100
message:
  Renaming of all (normally) linked with this famous "ContactLaw1". Thanks to Vaclav for his scripts !
renamed:
  pkg/dem/DataClass/InteractionPhysics/ContactLaw1Interaction.cpp => pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp
  pkg/dem/DataClass/InteractionPhysics/ContactLaw1Interaction.hpp => pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp
  pkg/dem/Engine/Functor/CL1Relationships.cpp => pkg/dem/Engine/Functor/RockJointLawRelationships.cpp
  pkg/dem/Engine/Functor/CL1Relationships.hpp => pkg/dem/Engine/Functor/RockJointLawRelationships.hpp
  pkg/dem/Engine/GlobalEngine/ContactLaw1.cpp => pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp
  pkg/dem/Engine/GlobalEngine/ContactLaw1.hpp => pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp
modified:
  attic/pkg/dem/PreProcessor/SimpleShear.cpp
  pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp
  pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp
  pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp
  pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp
  py/system.py
  pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp
  pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp
  pkg/dem/Engine/Functor/RockJointLawRelationships.cpp
  pkg/dem/Engine/Functor/RockJointLawRelationships.hpp
  pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp
  pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp


--
lp:yade
https://code.launchpad.net/~yade-dev/yade/trunk

Your team Yade developers is subscribed to branch lp:yade.
To unsubscribe from this branch go to https://code.launchpad.net/~yade-dev/yade/trunk/+edit-subscription.
=== modified file 'attic/pkg/dem/PreProcessor/SimpleShear.cpp'
--- attic/pkg/dem/PreProcessor/SimpleShear.cpp	2010-02-02 09:59:57 +0000
+++ attic/pkg/dem/PreProcessor/SimpleShear.cpp	2010-02-02 14:27:14 +0000
@@ -16,8 +16,8 @@
 #include <yade/lib-miniWm3/Wm3Math.h>
 
 #include <yade/pkg-dem/CohesiveFrictionalMat.hpp>
-#include <yade/pkg-dem/ContactLaw1.hpp>
-#include <yade/pkg-dem/CL1Relationships.hpp>
+#include <yade/pkg-dem/RockJointLaw.hpp>
+#include <yade/pkg-dem/RockJointLawRelationships.hpp>
 #include<yade/pkg-dem/GlobalStiffnessTimeStepper.hpp>
 #include <yade/pkg-dem/PositionOrientationRecorder.hpp>
 
@@ -272,7 +272,7 @@
 	interactionGeometryDispatcher->add("Ig2_Box_Sphere_ScGeom");
 
 	shared_ptr<InteractionPhysicsDispatcher> interactionPhysicsDispatcher(new InteractionPhysicsDispatcher);
-	shared_ptr<InteractionPhysicsFunctor> CL1Rel(new CL1Relationships);
+	shared_ptr<InteractionPhysicsFunctor> CL1Rel(new RockJointLawRelationships);
 	interactionPhysicsDispatcher->add(CL1Rel);
 
 	shared_ptr<BoundDispatcher> boundDispatcher	= shared_ptr<BoundDispatcher>(new BoundDispatcher);
@@ -298,7 +298,7 @@
 	rootBody->engines.push_back(shared_ptr<Engine>(new InsertionSortCollider));
 	rootBody->engines.push_back(interactionGeometryDispatcher);
 	rootBody->engines.push_back(interactionPhysicsDispatcher);
-	rootBody->engines.push_back(shared_ptr<Engine>(new ContactLaw1));
+	rootBody->engines.push_back(shared_ptr<Engine>(new RockJointLaw));
 	if(gravApplied)
 		rootBody->engines.push_back(gravityCondition);
 	if(shearApplied)

=== modified file 'pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp'
--- pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp	2010-02-02 08:51:30 +0000
+++ pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp	2010-02-02 14:27:14 +0000
@@ -179,10 +179,10 @@
 			vector<shared_ptr<Engine> >::iterator itLast = ncb->engines.end();
 			for ( ;itFirst!=itLast; ++itFirst )
 			{
-				if ( ( *itFirst )->getClassName() == "ContactLaw1" ) 
+				if ( ( *itFirst )->getClassName() == "RockJointLaw" ) 
 				{
-					if(LOG) cout << "ContactLaw1 engine found" << endl;
-					myLdc =  YADE_PTR_CAST<ContactLaw1> ( *itFirst );
+					if(LOG) cout << "RockJointLaw engine found" << endl;
+					myLdc =  YADE_PTR_CAST<RockJointLaw> ( *itFirst );
 					coeff_dech = myLdc ->coeff_dech;
 				}
 			}

=== modified file 'pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp'
--- pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp	2009-12-09 17:11:51 +0000
+++ pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp	2010-02-02 14:27:14 +0000
@@ -13,7 +13,7 @@
 #include<yade/core/Body.hpp>
 #include <Wm3Vector3.h>
 #include<yade/lib-base/yadeWm3.hpp>
-#include<yade/pkg-dem/ContactLaw1.hpp>
+#include<yade/pkg-dem/RockJointLaw.hpp>
 
 /*! \brief To apply a constant normal rigidity shear for a parallelogram box (simple shear)
 
@@ -31,7 +31,7 @@
 class CinemKNCEngine : public PartialEngine
 {
 	private :
-		shared_ptr<ContactLaw1> myLdc;
+		shared_ptr<RockJointLaw> myLdc;
 		Real	coeff_dech;	// the engine cares about it
 		Real	alpha	// angle from the lower plate to the left box (trigo wise), the Engine finds itself its value
 			,dalpha	// the increment over alpha

=== renamed file 'pkg/dem/DataClass/InteractionPhysics/ContactLaw1Interaction.cpp' => 'pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp'
--- pkg/dem/DataClass/InteractionPhysics/ContactLaw1Interaction.cpp	2009-11-21 10:36:08 +0000
+++ pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp	2010-02-02 14:27:14 +0000
@@ -6,10 +6,10 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include "ContactLaw1Interaction.hpp"
-
-
-ContactLaw1Interaction::ContactLaw1Interaction()
+#include "RockJointPhys.hpp"
+
+
+RockJointPhys::RockJointPhys()
 {
 	createIndex();
 
@@ -28,7 +28,7 @@
 
 }
 
-void ContactLaw1Interaction::SetBreakingState()
+void RockJointPhys::SetBreakingState()
 {
 	
 	//if (fragile) {
@@ -36,17 +36,17 @@
 	
 }
 
-ContactLaw1Interaction::~ContactLaw1Interaction()
+RockJointPhys::~RockJointPhys()
 {
 }
 
-// void ContactLaw1Interaction::postProcessAttributes(bool)
+// void RockJointPhys::postProcessAttributes(bool)
 // {
 // 
 // }
 
 
-YADE_PLUGIN((ContactLaw1Interaction));
+YADE_PLUGIN((RockJointPhys));
 
 YADE_REQUIRE_FEATURE(PHYSPAR);
 

=== renamed file 'pkg/dem/DataClass/InteractionPhysics/ContactLaw1Interaction.hpp' => 'pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp'
--- pkg/dem/DataClass/InteractionPhysics/ContactLaw1Interaction.hpp	2010-01-10 09:09:32 +0000
+++ pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp	2010-02-02 14:27:14 +0000
@@ -10,12 +10,12 @@
 
 #include<yade/pkg-dem/FrictPhys.hpp>
 
-/*! \brief Interaction for using ContactLaw1
+/*! \brief Interaction for using RockJointLaw
 
 This interaction is similar to CohesiveFrictionalContactInteraction. Among the differences are the unMax, previousun and previousFn (allowing to describe the inelastic unloadings in compression), no more shear and tension Adhesion, no more "fragile", "cohesionBroken" and "cohesionDisablesFriction"
  */
 
-class ContactLaw1Interaction : public FrictPhys
+class RockJointPhys : public FrictPhys
 {
 	public :
 		Real		unMax,		// the maximum value of penetration depth of the history of this interaction
@@ -31,17 +31,17 @@
 		Vector3r	initialPosition1,initialPosition2;
 
 	
-		ContactLaw1Interaction();
-		virtual ~ContactLaw1Interaction();
+		RockJointPhys();
+		virtual ~RockJointPhys();
 		void SetBreakingState ();
 	REGISTER_ATTRIBUTES(FrictPhys,(unMax)(previousun)(previousFn)(initialOrientation1)(initialOrientation2)(orientationToContact1)(orientationToContact2)(currentContactOrientation)(initialContactOrientation)(initialPosition1)(initialPosition2)(forMaxMoment)(kr));
-	REGISTER_CLASS_NAME(ContactLaw1Interaction);
+	REGISTER_CLASS_NAME(RockJointPhys);
 	REGISTER_BASE_CLASS_NAME(FrictPhys);
 
-	REGISTER_CLASS_INDEX(ContactLaw1Interaction,FrictPhys);
+	REGISTER_CLASS_INDEX(RockJointPhys,FrictPhys);
 
 };
 
-REGISTER_SERIALIZABLE(ContactLaw1Interaction);
+REGISTER_SERIALIZABLE(RockJointPhys);
 
 

=== renamed file 'pkg/dem/Engine/Functor/CL1Relationships.cpp' => 'pkg/dem/Engine/Functor/RockJointLawRelationships.cpp'
--- pkg/dem/Engine/Functor/CL1Relationships.cpp	2010-02-01 15:20:54 +0000
+++ pkg/dem/Engine/Functor/RockJointLawRelationships.cpp	2010-02-02 14:27:14 +0000
@@ -6,9 +6,9 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include"CL1Relationships.hpp"
+#include"RockJointLawRelationships.hpp"
 #include<yade/pkg-dem/ScGeom.hpp>
-#include<yade/pkg-dem/ContactLaw1Interaction.hpp>
+#include<yade/pkg-dem/RockJointPhys.hpp>
 // #include<yade/pkg-dem/SDECLinkGeometry.hpp> // FIXME - I can't dispatch by SDECLinkGeometry <-> ScGeom !!?
 // #include<yade/pkg-dem/SDECLinkPhysics.hpp> // FIXME
 #include<yade/pkg-dem/CohesiveFrictionalMat.hpp>
@@ -16,7 +16,7 @@
 #include<yade/core/Scene.hpp>
 
 
-CL1Relationships::CL1Relationships()
+RockJointLawRelationships::RockJointLawRelationships()
 {
 	betaR = 0.12;
 	setCohesionNow = false;
@@ -37,7 +37,7 @@
 //
 //
 
-void CL1Relationships::go(	  const shared_ptr<PhysicalParameters>& b1 // CohesiveFrictionalMat
+void RockJointLawRelationships::go(	  const shared_ptr<PhysicalParameters>& b1 // CohesiveFrictionalMat
 					, const shared_ptr<PhysicalParameters>& b2 // CohesiveFrictionalMat
 					, const shared_ptr<Interaction>& interaction)
 {
@@ -58,8 +58,8 @@
 		if(!interaction->interactionPhysics)
 		{
 //std::cerr << " isNew, id1: " << interaction->getId1() << " id2: " << interaction->getId2()  << "\n";
-			interaction->interactionPhysics = shared_ptr<ContactLaw1Interaction>(new ContactLaw1Interaction());
-			ContactLaw1Interaction* contactPhysics = YADE_CAST<ContactLaw1Interaction*>(interaction->interactionPhysics.get());
+			interaction->interactionPhysics = shared_ptr<RockJointPhys>(new RockJointPhys());
+			RockJointPhys* contactPhysics = YADE_CAST<RockJointPhys*>(interaction->interactionPhysics.get());
 
 			Real Ea 	= sdec1->young;
 			Real Eb 	= sdec2->young;
@@ -141,7 +141,7 @@
 		{	
 			// FIXME - are those lines necessary ???? what they are doing in fact ???
 			// ANSWER - they are used when you setCohesionNow (contact isNew not)
-			ContactLaw1Interaction* contactPhysics = YADE_CAST<ContactLaw1Interaction*>(interaction->interactionPhysics.get());
+			RockJointPhys* contactPhysics = YADE_CAST<RockJointPhys*>(interaction->interactionPhysics.get());
 
 			contactPhysics->kn = contactPhysics->initialKn;
 			contactPhysics->ks = contactPhysics->initialKs;
@@ -188,6 +188,6 @@
 	}
 #endif
 };
-YADE_PLUGIN((CL1Relationships));
+YADE_PLUGIN((RockJointLawRelationships));
 
 YADE_REQUIRE_FEATURE(PHYSPAR);

=== renamed file 'pkg/dem/Engine/Functor/CL1Relationships.hpp' => 'pkg/dem/Engine/Functor/RockJointLawRelationships.hpp'
--- pkg/dem/Engine/GlobalEngine/ContactLaw1.cpp	2010-02-02 11:05:09 +0000
+++ pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp	2010-02-02 14:27:14 +0000
@@ -6,10 +6,10 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include "ContactLaw1.hpp"
+#include "RockJointLaw.hpp"
 #include<yade/pkg-dem/CohesiveFrictionalMat.hpp>
 #include<yade/pkg-dem/ScGeom.hpp>
-#include<yade/pkg-dem/ContactLaw1Interaction.hpp>
+#include<yade/pkg-dem/RockJointPhys.hpp>
 #include<yade/pkg-dem/SDECLinkPhysics.hpp>
 #include<yade/core/Omega.hpp>
 #include<yade/core/Scene.hpp>
@@ -19,7 +19,11 @@
 Vector3r translation_vect (0.10,0,0);
 
 
-ContactLaw1::ContactLaw1() : GlobalEngine()
+// <<<<<<< TREE
+RockJointLaw::RockJointLaw() : GlobalEngine()
+// =======
+// ContactLaw1::ContactLaw1() : GlobalEngine()
+// >>>>>>> MERGE-SOURCE
 {
 	sdecGroupMask=1;
 	momentRotationLaw = true;
@@ -29,7 +33,7 @@
 
 
 
-void ContactLaw1::action(Scene* ncb)
+void RockJointLaw::action(Scene* ncb)
 {
     shared_ptr<BodyContainer>& bodies = ncb->bodies;
 
@@ -55,7 +59,7 @@
 		CohesiveFrictionalMat* de1 			= YADE_CAST<CohesiveFrictionalMat*>((*bodies)[id1]->physicalParameters.get());
 		CohesiveFrictionalMat* de2 			= YADE_CAST<CohesiveFrictionalMat*>((*bodies)[id2]->physicalParameters.get());
 		ScGeom* currentContactGeometry		= YADE_CAST<ScGeom*>(contact->interactionGeometry.get());
-		ContactLaw1Interaction* currentContactPhysics = YADE_CAST<ContactLaw1Interaction*> (contact->interactionPhysics.get());
+		RockJointPhys* currentContactPhysics = YADE_CAST<RockJointPhys*> (contact->interactionPhysics.get());
 
 		Vector3r& shearForce 			= currentContactPhysics->shearForce;
 
@@ -301,7 +305,7 @@
 
 }
 
-YADE_PLUGIN((ContactLaw1));
+YADE_PLUGIN((RockJointLaw));
 
 YADE_REQUIRE_FEATURE(PHYSPAR);
 

=== renamed file 'pkg/dem/Engine/GlobalEngine/ContactLaw1.hpp' => 'pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp'
--- pkg/dem/Engine/GlobalEngine/ContactLaw1.hpp	2010-02-02 11:05:09 +0000
+++ pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp	2010-02-02 14:27:14 +0000
@@ -18,15 +18,19 @@
 This contact Law is inspired by CohesiveFrictionalContactLaw (inspired itselve directly from the work of Plassiard & Belheine, see the corresponding articles in "Annual Report 2006" in http://geo.hmg.inpg.fr/frederic/Discrete_Element_Group_FVD.html for example). It allows so to set moments, cohesion, tension limit and (that's the difference) inelastic unloadings in compression between bodies.
 All that concerned brokenBodies (this flag and the erosionactivated one) and the useless "iter" has been suppressed.
 
-The Relationsships corresponding are CL1Relationships, where the rigidities, the friction angles (with their tan()), and the orientations of the interactions are calculated. No more cohesion and tension limits are computed for all the interactions
+The Relationsships corresponding are RockJointLawRelationships, where the rigidities, the friction angles (with their tan()), and the orientations of the interactions are calculated. No more cohesion and tension limits are computed for all the interactions
 To use it you should also use :
 - CohesiveFrictionalMat for the bodies, with "isCohesive" = 1 (A verifier ce dernier point)
-- CL1Relationships (=> which involves interactions of "ContactLaw1Interaction" type)
+- RockJointLawRelationships (=> which involves interactions of "RockJointPhys" type)
 
  */
 
 
-class ContactLaw1 : public GlobalEngine
+// <<<<<<< TREE
+class RockJointLaw : public GlobalEngine
+// =======
+// class ContactLaw1 : public GlobalEngine
+// >>>>>>> MERGE-SOURCE
 {
 /// Attributes
 	public :
@@ -35,13 +39,19 @@
 		bool momentRotationLaw;
 		bool momentAlwaysElastic;	// if true the value of the momentum (computed only if momentRotationLaw !!) is not limited by a plastic threshold
 	
-		ContactLaw1();
+		RockJointLaw();
 		void action(Scene*);
+// <<<<<<< TREE
 	REGISTER_ATTRIBUTES(GlobalEngine,(sdecGroupMask)(momentRotationLaw)(coeff_dech)(momentAlwaysElastic));
-	REGISTER_CLASS_NAME(ContactLaw1);
+	REGISTER_CLASS_NAME(RockJointLaw);
 	REGISTER_BASE_CLASS_NAME(GlobalEngine);
+// =======
+// 	REGISTER_ATTRIBUTES(GlobalEngine,(sdecGroupMask)(momentRotationLaw)(coeff_dech)(momentAlwaysElastic));
+// 	REGISTER_CLASS_NAME(ContactLaw1);
+// 	REGISTER_BASE_CLASS_NAME(GlobalEngine);
+// >>>>>>> MERGE-SOURCE
 };
 
-REGISTER_SERIALIZABLE(ContactLaw1);
+REGISTER_SERIALIZABLE(RockJointLaw);
 
 

=== modified file 'py/system.py'
--- py/system.py	2010-01-21 07:53:17 +0000
+++ py/system.py	2010-02-02 14:27:14 +0000
@@ -105,6 +105,10 @@
 	'Law2_Dem3Dof_Elastic_Elastic':'Law2_Dem3Dof_FrictPhys_Basic', # Sun Jan 10 10:00:25 2010, vaclav@flux
 	'Law2_Dem3Dof_FrictPhys_Basic':'Law2_Dem3DofGeom_FrictPhys_Basic', # Sun Jan 10 10:01:27 2010, vaclav@flux
 	'Ip2_FrictMat_FrictMat_NormShearPhys':'Ip2_FrictMat_FrictMat_FrictPhys', # Sun Jan 10 10:07:40 2010, vaclav@flux
+	'ContactLaw1':'RockJointLaw', # Tue Feb  2 14:53:49 2010, jduriez@c1solimara-l
+	'ContactLaw1':'RockJointLaw', # Tue Feb  2 14:54:40 2010, jduriez@c1solimara-l
+	'ContactLaw1Interaction':'RockJointPhys', # Tue Feb  2 14:55:34 2010, jduriez@c1solimara-l
+	'CL1Relationships':'RockJointLawRelationships', # Tue Feb  2 14:58:02 2010, jduriez@c1solimara-l
 	### END_RENAMED_CLASSES_LIST ### (do not delete this line; scripts/rename-class.py uses it
 }
--- pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp	2010-02-01 15:20:54 +0000
+++ pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp	2010-02-02 14:27:14 +0000
@@ -13,7 +13,7 @@
 #include<yade/core/Body.hpp>
 #include <Wm3Vector3.h>
 #include<yade/lib-base/yadeWm3.hpp>
-#include<yade/pkg-dem/ContactLaw1.hpp>
+#include<yade/pkg-dem/RockJointLaw.hpp>
 
 
 /*! \brief To apply a constant normal stress shear for a parallelogram box (simple shear)
@@ -33,8 +33,8 @@
 class CinemCNCEngine : public PartialEngine
 {
 	private :
-		shared_ptr<ContactLaw1> myLdc;
-		Real	coeff_dech;	// in the case of the use of "ContactLaw1" for ex where kn(unload)#kn(load). The engine cares to find the value at the first run
+		shared_ptr<RockJointLaw> myLdc;
+		Real	coeff_dech;	// in the case of the use of "RockJointLaw" for ex where kn(unload)#kn(load). The engine cares to find the value at the first run
 		Real	alpha	// angle from the lower plate to the left box (trigo wise), the Engine finds itself its value
 			,dalpha	// the increment over alpha, due to vertical displacement of upper box
 			,gamma	// horizontal displacement done since the launch of the calcul first step

=== modified file 'pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp'
--- pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp	2010-02-02 08:51:30 +0000
+++ pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp	2010-02-02 14:27:14 +0000
@@ -166,9 +166,9 @@
 			vector<shared_ptr<Engine> >::iterator itLast = ncb->engines.end();
 			for ( ;itFirst!=itLast; ++itFirst )
 			{
-				if ( ( *itFirst )->getClassName() == "ContactLaw1" ) 
+				if ( ( *itFirst )->getClassName() == "RockJointLaw" ) 
 				{
-					myLdc =  YADE_PTR_CAST<ContactLaw1> ( *itFirst );
+					myLdc =  YADE_PTR_CAST<RockJointLaw> ( *itFirst );
 					coeff_dech = myLdc ->coeff_dech;
 					if(LOG) cout << "My ContactLaw engine found, de coeff_dech = " << coeff_dech << endl;
 				}
@@ -197,7 +197,7 @@
 	Real Hcurrent = (topbox->physicalParameters.get())->se3.position.Y();
 	Real Fdesired = F_0 + KnC * 1.0e9 * Scontact * (Hcurrent-Y0); // The value of the force desired
 
 // Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de ContactLaw1 :
 	if( F_sup.Y() > Fdesired )	// cas ou l'on va monter la plaq <=> (normalemt) a une decharge
 		stiffness *= coeff_dech;
 
@@ -197,7 +197,7 @@
 	Real Fdesired = F_0 + KnC * 1.0e9 * Scontact * (Hcurrent-Y0); // The value of the force desired
 
-// Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de ContactLaw1 :
+// Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de RockJointLaw :
 	if( F_sup.Y() > Fdesired )	// cas ou l'on va monter la plaq <=> (normalemt) a une decharge
 		stiffness *= coeff_dech;

=== modified file 'pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp'
--- pkg/dem/Engine/Functor/CL1Relationships.hpp	2009-12-07 19:41:08 +0000
+++ pkg/dem/Engine/Functor/RockJointLawRelationships.hpp	2010-02-02 14:27:14 +0000
@@ -10,16 +10,16 @@
 
 #include<yade/pkg-common/InteractionPhysicsFunctor.hpp>
 
 /*! \brief The RelationShips for using ContactLaw1
 
-In these RelationShips all the attributes of the interactions (which are of ContactLaw1Interaction type) are computed.
+In these RelationShips all the attributes of the interactions (which are of RockJointPhys type) are computed.
 WARNING : as in the others Relationships most of the attributes are computed only once : when the interaction is "new"
  */
 
-class CL1Relationships : public InteractionPhysicsFunctor
+class RockJointLawRelationships : public InteractionPhysicsFunctor
 {
 	public :
-		CL1Relationships();
+		RockJointLawRelationships();
 
 		virtual void go(	const shared_ptr<PhysicalParameters>& b1,
 					const shared_ptr<PhysicalParameters>& b2,
@@ -35,11 +35,11 @@
 		long iter;//REMOVE THIS
 
 	FUNCTOR2D(CohesiveFrictionalMat,CohesiveFrictionalMat);
-	REGISTER_CLASS_NAME(CL1Relationships);
+	REGISTER_CLASS_NAME(RockJointLawRelationships);
 	REGISTER_BASE_CLASS_NAME(InteractionPhysicsFunctor);
 	REGISTER_ATTRIBUTES(InteractionPhysicsFunctor,(betaR)(setCohesionNow)(setCohesionOnNewContacts));
 };
 
-REGISTER_SERIALIZABLE(CL1Relationships);
+REGISTER_SERIALIZABLE(RockJointLawRelationships);
 
 
@@ -10,16 +10,16 @@
 #include<yade/pkg-common/InteractionPhysicsFunctor.hpp>
 
-/*! \brief The RelationShips for using ContactLaw1
+/*! \brief The RelationShips for using RockJointLaw
 

=== renamed file 'pkg/dem/Engine/GlobalEngine/ContactLaw1.cpp' => 'pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp'